@@ -37,7 +37,7 @@ from ...grids.search import BooleanSearchFilter
 from edbob.pyramid.progress import SessionProgress
 from .. import SearchableAlchemyGridView, CrudView, View
 
-import rattail
+from rattail import enum
 from rattail import batches
 from ...db import Session
 from rattail.db.model import Batch
@@ -119,7 +119,7 @@ class BatchCrud(CrudView):
 
     def fieldset(self, model):
         fs = self.make_fieldset(model)
-        fs.action_type.set(renderer=EnumFieldRenderer(rattail.BATCH_ACTION))
+        fs.action_type.set(renderer=EnumFieldRenderer(enum.BATCH_ACTION))
         fs.executed.set(renderer=PrettyDateTimeFieldRenderer(from_='utc'))
         fs.configure(
             include=[
